// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0

Page {

    AdScreen {
        id: ad
        anchors.bottom: parent.bottom
        z: 3
    }

    Constants {
        id: constants
    }

    tools: toolbar

    property string lastUpdateTime: constants.currentDateTimeFormatted();
    property string currentUrl: constants.lineStatusUrl
    property string responseXml: qsTr("")

    PopupDialog {
        id: popupDialog
    }

    Component.onCompleted: {
        refresh();
    }
    function refresh() {
        constants.refresh(this, lastUpdateTime, xmlModel, currentUrl);
    }

    Rectangle {
        id: rootContainer
        anchors.fill: parent
        color: "black"
        Rectangle {
            id: tflHeader
            height: constants.headerHeight
            width: parent.width
            color: "black"
            z: 1
            Text {
                text: qsTr("Line Status")
                font.pointSize: constants.listHeaderFontPointSize
                anchors.verticalCenter: parent.verticalCenter
                anchors.left: parent.left
                anchors.leftMargin: 15
                color: "white";
            }
        }
        ListView {
            id: tfl
            anchors.top: tflHeader.bottom
            height: parent.height - tflHeader.height - ad.height + 20
            width: parent.width
            model: xmlModel
            delegate: delegate
            snapMode: ListView.NoSnap
            ScrollDecorator {
                 flickableItem: tfl
            }
        }
    }

    Component {
         id: delegate
         Item {
             id: delegateRow
             height: constants.listItemHeight
             width: parent.width
             Rectangle {
                 height: parent.height
                 width: parent.width * 0.6
                 border.color: constants.borderColor
                 border.width: constants.borderWidth
                 color: constants.getLineColor(lineName);
                 Text {
                     text: qsTr(lineName);
                     font.pointSize: constants.listFontPointSize
                     color:constants. listFontColor
                     anchors.left: parent.left
                     anchors.leftMargin: constants.listLeftRightMargin
                     anchors.verticalCenter: parent.verticalCenter
               }
             }
             Rectangle {
                 color: statusId === "GS" ? "green" : statusId === "MD" ? "orange" : "red";
                 anchors.right: parent.right
                 width: parent.width * 0.4
                 height: constants.listItemHeight
                 border.color: constants.borderColor
                 border.width: constants.borderWidth
             Text {
                 text: qsTr(statusDescription);
                 anchors.left: parent.left
                 anchors.leftMargin: constants.listLeftRightMargin
                 font.pointSize: constants.listFontPointSize
                 color: constants.listFontColor
                 anchors.verticalCenter: parent.verticalCenter
            }
             MouseArea {
                 anchors.fill: parent
                 onClicked: {
                     if (lineStatusDetails !== "") {
                         popupDialog.message = "<b>" + lineName + "</b>: <br/>" + lineStatusDetails;
                         popupDialog.open()
                     }
                 }
             }
          }
       }
    }

    XmlListModel {
        id: xmlModel
        xml: responseXml
        query: "/ArrayOfLineStatus/LineStatus"
        namespaceDeclarations: "declare default element namespace 'http://webservices.lul.co.uk/';"

        XmlRole { name: "lineSatusId"; query: "@ID/string()" }
        XmlRole { name: "lineStatusDetails"; query: "@StatusDetails/string()" }

        XmlRole { name: "lineId"; query: "Line/@ID/string()" }
        XmlRole { name: "lineName"; query: "Line/@Name/string()" }

        XmlRole { name: "statusId"; query: "Status/@ID/string()" }
        XmlRole { name: "statusCssClass"; query: "Status/@CssClass/string()" }
        XmlRole { name: "statusDescription"; query: "Status/@Description/string()" }
        XmlRole { name: "statusIsActive"; query: "Status/@IsActive/string()" }
        onStatusChanged: {
            if (status == XmlListModel.Error){
                tflBusyIndicator.setVisbility = false
                tflBusyIndicator.setRunning = false
                popupDialog.title = "Error"
                popupDialog.message = status
                popupDialog.open()
            } else if (status == XmlListModel.Loading) {
                tflBusyIndicator.setVisbility = true
                tflBusyIndicator.setRunning = true
            } else if (status == XmlListModel.Ready) {
                tflBusyIndicator.setVisbility = false
                tflBusyIndicator.setRunning = false
            }
        }
    }

    ToolBarLayout {
            id: toolbar
            ToolIcon { iconId: "toolbar-back"; onClicked: { menu.close(); pageStack.pop(); }  }
            ToolIcon { iconId: "toolbar-refresh"; onClicked: { refresh() } }
            ToolIcon { iconId: "toolbar-view-menu" ; onClicked: menu.open(); }
        }

    Menu {
        id: menu
        visualParent: pageStack
        MenuLayout {
            MenuItem {
                text: "Refresh";
                onClicked: {
                    refresh()
                }
            }
            MenuItem {
                text: "Show incidents only";
                onClicked: {
                    currentUrl = constants.lineStatusUrlIncidentsOnly
                    refresh()
                }
            }
            MenuItem {
                text: "Show all"; onClicked: {
                    currentUrl = constants.lineStatusUrl
                    refresh()
                }
            }
        }
    }
}
