// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0

Component {
    id: head
    Rectangle {
      property string headerBackgroud: "black"
      id: searchRectangle
      anchors.topMargin: constants.headerHeight
      width: parent.width
      height: (state == "visible") ? 55 : 0
      visible: (state == "visible") ? true : false
      color: headerBackgroud
      TextField {
            id: searchField
            anchors.fill: parent
            anchors.margins: 5
            focus: false
            visible: parent.visible
            placeholderText: "Search"
            onTextChanged: {
                if (searchField.text.length > 0) {
                    searchIcon.visible = false;
                    deleteIcon.visible = true;
                } else {
                    searchIcon.visible = true;
                    deleteIcon.visible = false;
                }

                if (activeFocus) {
                    if(filterTimer.running) {
                        filterTimer.restart()
                    } else {
                        filterTimer.start()
                    }
                }
            }

            onActiveFocusChanged: {
                if(searchField.activeFocus) {
                    autoHideTimer.stop();
                    listView.positionViewAtBeginning();
                }
                else {
                    autoHideTimer.restart();
                }
            }
            Timer {
               id: filterTimer
               interval: 1500
               running: false
               repeat: false
               onTriggered: {
                   queryText = searchField.text;
               }
            }

            ToolIcon {
              id: searchIcon
              iconSource: "image://theme/icon-m-common-search";
              anchors.verticalCenter: parent.verticalCenter
              anchors.right: parent.right
              visible: parent.visible
            }
            ToolIcon {
              id: deleteIcon
              iconSource: "image://theme/icon-m-input-clear";
              anchors.verticalCenter: parent.verticalCenter
              anchors.right: parent.right
              visible: false
              onClicked: {
                  searchField.text = "";
              }
            }
      }

      Component.onCompleted: listView.headerItem = searchRectangle
      Component.onDestruction: listView.headerItem = null

      state: "visible"
      onStateChanged: {
          if (state == "visible") {
              showAnimation.start();
              listView.positionViewAtBeginning();
          }
          if (state == "hidden") {
              hideAnimation.start();
          }
      }

      ParallelAnimation {
          id: showAnimation
          PropertyAnimation { target: searchRectangle; property: "visible"; from: "false"; to: "true" }
          NumberAnimation { target: searchRectangle; property: "opacity"; from: 0; to: 1; duration: 250;}
      }

      ParallelAnimation {
          id: hideAnimation
          NumberAnimation { target: searchRectangle; property: "opacity"; from: 1; to: 0; duration: 250;}
          PropertyAnimation { target: searchRectangle; property: "visible"; from: "true"; to: "false" }
      }


      // Autohide timer
      Timer {
        id: autoHideTimer
        interval: 2000
        onTriggered: {
            if (!searchField.activeFocus && searchField.text.length < 1)
             searchRectangle.state = "hidden"
        }
        running: true
      }

      function startTimer(){
        // Doesn't hide search field if it has focus
        if (!searchField.activeFocus)
          autoHideTimer.restart();
        }
    }
}
